Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(564)

Unified Diff: milo/appengine/rpc/buildinfo.go

Issue 2950563003: [milo] buildinfo -> rpc (Closed)
Patch Set: actually include things Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « milo/appengine/frontend/main.go ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: milo/appengine/rpc/buildinfo.go
diff --git a/milo/appengine/buildinfo/service.go b/milo/appengine/rpc/buildinfo.go
similarity index 83%
rename from milo/appengine/buildinfo/service.go
rename to milo/appengine/rpc/buildinfo.go
index 04bd147a49affa6e8ae0f5152ae25f94c3988a61..451873a66ccf829bc5e3eb584ebec606d4069e47 100644
--- a/milo/appengine/buildinfo/service.go
+++ b/milo/appengine/rpc/buildinfo.go
@@ -2,7 +2,7 @@
// Use of this source code is governed under the Apache License, Version 2.0
// that can be found in the LICENSE file.
-package buildinfo
+package rpc
import (
"github.com/luci/luci-go/grpc/grpcutil"
@@ -16,18 +16,18 @@ import (
"golang.org/x/net/context"
)
-// Service is a BuildInfoServer implementation.
-type Service struct {
+// BuildInfoService is a BuildInfoServer implementation.
+type BuildInfoService struct {
// BuildBot is the BuildInfoProvider for the BuildBot service.
BuildBot buildbot.BuildInfoProvider
// Swarming is the BuildInfoProvider for the Swarming service.
Swarming swarming.BuildInfoProvider
}
-var _ milo.BuildInfoServer = (*Service)(nil)
+var _ milo.BuildInfoServer = (*BuildInfoService)(nil)
// Get implements milo.BuildInfoServer.
-func (svc *Service) Get(c context.Context, req *milo.BuildInfoRequest) (*milo.BuildInfoResponse, error) {
+func (svc *BuildInfoService) Get(c context.Context, req *milo.BuildInfoRequest) (*milo.BuildInfoResponse, error) {
projectHint := cfgtypes.ProjectName(req.ProjectHint)
if projectHint != "" {
if err := projectHint.Validate(); err != nil {
« no previous file with comments | « milo/appengine/frontend/main.go ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698